﻿// *****************************************************************
// *                                                               *
// *       Copyright (c) Fast Corporation, 2017                    *
// *                                                               *
// *   All Rights Reserved.  Unpublished rights  reserved  under   *
// *   the copyright laws of the Japan.                            *
// *                                                               *
// *   The software contained on this media  is  proprietary  to   *
// *   and  embodies  the  confidential  technology  of  Fast      *
// *   Corporation.  Possession, use,  duplication  or             *
// *   dissemination of the software and media is authorized only  *
// *   pursuant to a valid written license from Fast Corporation.  *
// *                                                               *
// *****************************************************************


using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;


// -----------------------------------------------------------------
// FVIL Sample Program
// メインダイアログ
//
// 作成者 : N.Kubo
//
// 履歴 : 2017/8/10 初版
//
// Affine Sample Program
// -----------------------------------------------------------------


namespace affine
{
    public partial class FormAFFINE_SAMPLE : Form
    {        

    
        //取込クラス
        private FVIL.Video.CFviVideo m_video = null;

        //　affine変換インスタンス準備
        FVIL.GeoTrans.CFviAffine m_affine = new FVIL.GeoTrans.CFviAffine();
        FVIL.Data.CFviImage m_image = new FVIL.Data.CFviImage();
        FVIL.Data.CFviImage m_dst = new FVIL.Data.CFviImage();


     
        //表示用オーバーレイクラス宣言
        private FVIL.GDI.CFviOverlay m_overlay = new FVIL.GDI.CFviOverlay();

        //処理時間計測クラス
        private FVIL.CFviTimeCounter m_timer = new FVIL.CFviTimeCounter();

        //iniファイル設定フォーム
        Form_BROWSEINI formBroseIni = new Form_BROWSEINI();

        //iniファイル名（フルパス）
        public string m_strIniFilePath;


        //ビデオデバイスのオープン状態
        private bool m_flgVideoOpened;

        //時間測定用
        private double msec = 0;


        public FormAFFINE_SAMPLE()
        {
            InitializeComponent();
        }

        private void cFviImageView1_Load(object sender, EventArgs e)
        {
            dialogLicence licence_dialog = new dialogLicence();

            if (licence_dialog.ShowDialog(this) != DialogResult.OK)
            {
                this.Close();
                //使用許諾が得られない場合はサンプルプログラムの動作を終了
                return;
            }
        

            // FVILの初期化
            // アプリケーションを起動した後、 この関数を呼び出してライブラリを初期化してください。 
            //  この時、ライセンスの認証が行われます。試用期間中であっても、この処理は必ず行う必要が有ります。 
            // 初期化を行わなかった場合は、プロテクトされたクラスの実行ができません。
            FVIL._SetUp.InitVisionLibrary();

            //状態変数の初期化
            m_flgVideoOpened = false;

            //計測時間テキストボックス初期化
            TextBoxTime.Text = "0";

            //トリガモードコンボボックス初期化
            ComboBoxTrigger.Items.Clear();
            ComboBoxTrigger.Items.Add("ノーマル");
            ComboBoxTrigger.Items.Add("内部トリガ");
            ComboBoxTrigger.Items.Add("外部トリガ");
            ComboBoxTrigger.SelectedIndex = 0;


            // 描画imageのセット
            cFviImageView1.Image = m_image;
            // オーバーレイの追加
            cFviImageView1.Display.Overlays.Add(m_overlay);
            // iniファイル選択
            fnSetIniFile();

        }


        /// <summary>
        /// iniファイル選択関数
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// iniファイルの選択をします。
        /// </remarks>
        private void fnSetIniFile()
        {
            msec = 0;
            // iniファイルの選択
            string strIniFilePath;

            strIniFilePath = "";
            if (formBroseIni.ShowDialog(this) == DialogResult.OK)
            {
                strIniFilePath = formBroseIni.strIniFilePath;
            }

            if (strIniFilePath.Length > 0)
            {
                try
                {
                    // 設定ファイルのロードとデバイスオープン
                    m_video = FVIL.Video.Function.CreateInstance(strIniFilePath);
                    // 取込画像を正規化
                    m_video.ChangeImageSize(m_image);
                    // 結果格納画像を取り込み画像サイズに合わせる
                    m_video.ChangeImageSize(m_image);


                        m_flgVideoOpened = true;

                    // ステータス表示の更新
                    // トリガモードの取得
                    ComboBoxTrigger.SelectedIndex = (int)m_video.Trigger;
                    // カメラ露光時間の取得
                    if (m_video.DeviceType != FVIL.Video.DeviceType.RICE001)
                    {
                        NumericUpDownExposure.Value = m_video.ExposureTime;
                    }
                    
                }
                catch (FVIL.CFviException ex)
                {
                    // エラー処理
                    MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                catch (System.Exception ex)
                {
                    // エラー処理
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
            else if (formBroseIni.UseFileFlg == true)
            {
                    btnGrabOne.Enabled = false;
            }
            else
            {
                // iniファイルが未選択の場合はサンプルプログラムの動作を終了
                this.Close();
                return;
            }
        }

        /// <summary>
        /// Save Imageボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 表示画像保存。
        /// </remarks>
        private void ButtonSaveImage_Click(object sender, EventArgs e)
        {
            SaveFileDialog ofdlg = new SaveFileDialog();

            ofdlg.Filter = "画像ファイル(*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat)|*.bmp;*.dib;*.png;*.jpg;*.jpeg;*.tif;*.tiff;*.raw;*.pat";
            ofdlg.Filter += "|Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            ofdlg.Filter += "|Png ファイル (*.png)|*.png";
            ofdlg.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            ofdlg.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            ofdlg.Filter += "|Raw ファイル (*.raw)|*.raw";
            ofdlg.Filter += "|すべてのファイル (*.*)|*.*";
            ofdlg.OverwritePrompt = true;

            if (ofdlg.ShowDialog(this) == DialogResult.OK)
            {
                try
                {
                    //この関数は、簡易的に画像ファイルの保存を行う為のものです。 
                    //この関数で指定できないパラメータを指定する必要があれば、 各画像ファイルアクセスクラスを直接使用してください。 
                    FVIL.File.Function.SaveImageFile(ofdlg.FileName, cFviImageView1.Image);
                }
                catch (FVIL.CFviException ex)
                {
                    System.String msg = System.String.Format("ライブラリが例外を発行しました。code={0} func={1}", ex.ErrorCode, ex.Function);
                    switch (ex.ErrorCode)
                    {
                        case FVIL.ErrorCode.NOT_SUPPORTED:
                        case FVIL.ErrorCode.INVALID_OBJECT:
                            msg += "\r\n" + "サポートされていない画像オブジェクトです。";
                            msg += "\r\n" + "Raw 形式で保存してください。";
                            break;
                    }
                    //エラー処理
                    MessageBox.Show(msg, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                catch (Exception ex)
                {
                    //エラー処理
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
            }
        }


        /// <summary>
        /// x１ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 等倍で表示します。
        /// </remarks>
        private void ButtonMag1_Click(object sender, EventArgs e)
        {
            //画像の表示倍率の取得または設定を行います。1.0と指定すると等倍で表示します。
            //倍率値は、0.5とした場合は、幅・高さ共に1/2となり、面積が1/4になります。
            //3.0とした場合は、幅・高さ共に3倍となり、面積が9倍になります。

            //表示倍率の設定
            cFviImageView1.Display.Magnification = 1.0;

            //再描画
            cFviImageView1.Refresh();

        }


        /// <summary>
        /// Fitボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します。
        /// </remarks>
        private void ButtonFit_Click(object sender, EventArgs e)
        {
            //画像全体がビューのクライアント領域に表示できるように表示倍率を縮小(または拡大)します
            //表示倍率を調整
            cFviImageView1.FitImageSize();
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// ＋ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率に0.5加えた倍率で表示します。
        /// </remarks>
        private void ButtonPlus_Click(object sender, EventArgs e)
        {
            double Value = 0;
            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            //表示倍率の設定
            Value = Value + 0.5;
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// －ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 現在の倍率から0.5引いた倍率で表示します。ただし、倍率が０以下になる場合は倍率0.1で表示します。
        /// </remarks>
        private void ButtonMinus_Click(object sender, EventArgs e)
        {
            double Value = 0;
            //現倍率の取得
            Value = cFviImageView1.Display.Magnification;
            Value = Value - 0.5;
            if (Value <= 0)
            {
                //０以下を設定するとエラーになるので0.1を設定する
                Value = 0.1;
            }
            //表示倍率の設定
            cFviImageView1.Display.Magnification = Value;
            //再描画
            cFviImageView1.Refresh();

        }

        /// <summary>
        /// Grab Oneボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// カメラ取り込み。
        /// </remarks>
        private void btnGrabOne_Click(object sender, EventArgs e)
        {
            try
            {
                m_overlay.Figures.Clear();
                formBroseIni.UseFileFlg = false;

                m_video.ChangeImageSize(m_image);

                //デバイスタイプ
                FVIL.Video.CFviContinuousGrab contgrab;
                switch (m_video.DeviceType)
                {
                    case FVIL.Video.DeviceType.FVC05:
                    case FVIL.Video.DeviceType.FVC06:
                    case FVIL.Video.DeviceType.FVC07:
                    case FVIL.Video.DeviceType.GP440:
                    case FVIL.Video.DeviceType.RICE001:
                    case FVIL.Video.DeviceType.FV1300:

                        //時間測定開始
                        m_timer.Start();
                        //カメラ取り込み
                        m_video.GrabImageSync(m_image);
                        //時間測定終了
                        msec = m_timer.Stop();
                        break;
                    case FVIL.Video.DeviceType.FHC3312:
                        contgrab = ((FVIL.Video.CFviVideoFHC3312)m_video).ContinuousGrab;
                        ((FVIL.Video.CFviContinuousGrabFHC3312)contgrab).MemoryLock(m_image);
                        //時間測定開始
                        m_timer.Start();
                        //カメラ取り込み
                        contgrab.GrabSync(1);
                        //時間測定終了
                        msec = m_timer.Stop();
                        break;
                    case FVIL.Video.DeviceType.FHC3313:
                        contgrab = ((FVIL.Video.CFviVideoFHC3313)m_video).ContinuousGrab;
                        ((FVIL.Video.CFviContinuousGrabFHC3313)contgrab).MemoryLock(m_image);
                        //時間測定開始
                        m_timer.Start();
                        //カメラ取り込み
                        contgrab.GrabSync(1);
                        //時間測定終了
                        msec = m_timer.Stop();
                        break;
                    default:
                        break;
                }
                //測定時間表示
                TextBoxTime.Text = msec.ToString("0.000");

                //再描画
                cFviImageView1.Refresh();
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }


        /// <summary>
        /// LoadFile ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 入力画像ファイルのロード
        /// </remarks>
        private void btnLoadImageFile_Click(object sender, EventArgs e)
        {
            formBroseIni.UseFileFlg = true;
            //入力画像ファイルのロード
            openFileDialog1.FileName = null;
            openFileDialog1.Filter = "Bitmap ファイル (*.bmp;*.dib)|*.bmp;*.dib";
            openFileDialog1.Filter += "|Png ファイル (*.png)|*.png";
            openFileDialog1.Filter += "|Jpeg ファイル (*.jpg;*.jpeg)|*.jpg;*.jpeg";
            openFileDialog1.Filter += "|Tiff ファイル (*.tif;*.tiff)|*.tif;*.tiff";
            openFileDialog1.DefaultExt = "*.bmp";


            if ((openFileDialog1.FileNames.Length <= 0) && (openFileDialog1.ShowDialog(this) == DialogResult.Cancel))
            {
                return;
            }

            try
            {
                FVIL.File.Function.LoadImageFile(openFileDialog1.FileName, m_image, FVIL.PixelMode.Unpacking);
                m_dst.SetSize(m_image.ImageSize.ToSize(), m_image.ImageType, m_image.Channel);

            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            // 描画imageのセット
            cFviImageView1.Image = m_image;
            //再描画
            cFviImageView1.Refresh();
        }



        /// <summary>
        /// 2倍拡大ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 2倍率に拡大した画像を表示します。
        /// </remarks>
        private void btnEnlarge_Click(object sender, EventArgs e)
        {
            m_image.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);
            FVIL.GeoTrans.CFviScale scale = new FVIL.GeoTrans.CFviScale();
            try
            {


                //2倍に拡大
                scale.SrcImages[0] = m_image;
                scale.DstImages[0] = m_dst;

                //表示の始点は左上に設定
                scale.DstImages[0].Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);
                //Pos.y = 0;     


                scale.MagnificationOfHorz = 2.0;
                scale.MagnificationOfVert = 2.0;

                scale.Execute();
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

            // 描画imageのセット
            cFviImageView1.Image = m_dst;
            //再描画
            cFviImageView1.Refresh();

        }

     


        /// <summary>
        /// 1/2縮小 ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 画像を1/2に縮小して表示します
        /// </remarks>
        private void btnReduction_Click(object sender, EventArgs e)
        {

            m_image.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);
            m_dst.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);

            FVIL.GeoTrans.CFviScale scale = new FVIL.GeoTrans.CFviScale();

            try
            {
                //1/2縮小
                scale.SrcImages[0] = m_image;
                scale.DstImages[0] = m_dst;
                scale.MagnificationOfHorz = 0.5;        // 縮小率の指定
                scale.MagnificationOfVert = 0.5;

                //左上
                scale.DstImages[0].Window = new Rectangle(0, 0, m_image.HorzSize / 2, m_image.VertSize / 2);
                scale.Execute();

                // 右上
                scale.DstImages[0].Window = new Rectangle(m_image.HorzSize / 2, 0, m_image.HorzSize / 2, m_image.VertSize / 2);
                scale.Execute();

                // 左下
                scale.DstImages[0].Window = new Rectangle(0, m_image.VertSize / 2, m_image.HorzSize / 2, m_image.VertSize / 2);
                scale.Execute();

                // 右下
                scale.DstImages[0].Window = new Rectangle(m_image.HorzSize / 2, m_image.VertSize / 2, m_image.HorzSize / 2, m_image.VertSize / 2);
                scale.Execute();


                // 描画imageのセット
                cFviImageView1.Image = m_dst;
                //再描画
                cFviImageView1.Refresh();
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

        }


        /// <summary>
        /// 領域指定で拡大 ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ユーザーが指定した領域で拡大します
        /// </remarks>
        private void btnAreaEnlarge_Click(object sender, EventArgs e)
        {

            try
            {

                if (cFviImageView1.Display.OverlayProcarea.Active)
                {

                    cFviImageView1.Display.OverlayProcarea.Active = false;
                    FVIL.GeoTrans.CFviScale scale = new FVIL.GeoTrans.CFviScale();
                    m_dst.SetSize(m_image.ImageSize.ToSize(), m_image.ImageType, m_image.Channel);                   

                    //2倍に拡大
                    scale.SrcImages[0] = m_image;
                    scale.DstImages[0] = m_dst;

                    //拡大の倍率計算
                    double dblScaleX = (double)m_image.ImageSize.HorzSize / (double)m_image.Window.Width;
                    double dblScaleY = (double)m_image.ImageSize.VertSize / (double)m_image.Window.Height;


                    scale.MagnificationOfHorz = dblScaleX;
                    scale.MagnificationOfVert = dblScaleY;

                    //拡大実行
                    scale.Execute();


                    //変更したボタンを元に戻す
                    btnAreaEnlarge.Text = "領域指定して拡大";
                    btnEnlarge.Enabled = true;

                    if (formBroseIni.UseFileFlg == false)
                        btnGrabOne.Enabled = true;

                    btnLoadImageFile.Enabled = true;
                    btnReduction.Enabled = true;
                    btnShift.Enabled = true;
                    btnRotate.Enabled = true;


                    // 描画imageのセット    
                    cFviImageView1.Image = m_dst;

                    //再描画
                    cFviImageView1.Refresh();
                }
                else
                {
                    m_image.Window = new Rectangle(m_image.VertSize / 3, m_image.HorzSize / 3, m_image.VertSize / 3, m_image.HorzSize / 3);
                    cFviImageView1.Image = m_image;
                    cFviImageView1.Display.OverlayProcarea.Active = true;
    


                    btnAreaEnlarge.Text = "領域指定完了";

                    //領域指定中に他の処理が実行できないように変更
                    btnEnlarge.Enabled = false;
                    if (formBroseIni.UseFileFlg == false)
                        btnGrabOne.Enabled = false;
                    btnLoadImageFile.Enabled = false;
                    btnReduction.Enabled = false;
                    btnShift.Enabled = false;
                    btnRotate.Enabled = false;

                    //再描画
                    cFviImageView1.Refresh();

                }



            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }

               
            
        }


        /// <summary>
        /// 平行移動ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 指定した数値で平行移動した画像を表示します。
        /// </remarks>
        private void btnShift_Click(object sender, EventArgs e)
        {
            FormSift dlg = new FormSift();
            m_image.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);
            m_dst.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);


            if (dlg.ShowDialog() == DialogResult.OK)
            {

                try
                {
                    FVIL.GeoTrans.CFviShift sift = new FVIL.GeoTrans.CFviShift();


                    sift.SrcImages[0] = m_image;
                    sift.DstImages[0] = m_dst;

                    //移動量設定
                    sift.ShiftX = dlg.MoveX;
                    sift.ShiftY = dlg.MoveY;

                    sift.Execute();

                    // 描画imageのセット    
                    cFviImageView1.Image = m_dst;

                    //再描画
                    cFviImageView1.Refresh();
                }
                catch (FVIL.CFviException ex)
                {
                    //エラー処理
                    MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }
                catch (System.Exception ex)
                {
                    //エラー処理
                    MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
                }


            }
        }


        /// <summary>
        /// 回転ボタン
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// 指定した数値で回転した画像を表示します。
        /// </remarks>
        private void btnRotate_Click(object sender, EventArgs e)
        {
            
            FormRotate dlg = new FormRotate();
            FVIL.GeoTrans.CFviRotate rotate = new FVIL.GeoTrans.CFviRotate();

            FVIL.Data.CFviPoint pos = new FVIL.Data.CFviPoint();

            m_image.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);
            m_dst.Window = new Rectangle(0, 0, m_image.HorzSize, m_image.VertSize);

            try
            {
                if (dlg.ShowDialog() == DialogResult.OK)
                {
                    if (0 != (int)dlg.dAngle % 90 || 0 > dlg.dAngle)
                    {
                        rotate.SrcImages[0] = m_image;
                        rotate.DstImages[0] = m_dst;


                        pos.X = m_image.HorzSize / 2.0;
                        pos.Y = m_image.VertSize / 2.0;

                        //画像の中心を回転中心とする

                        rotate.Axis = pos;

                        rotate.Angle = new FVIL.Data.CFviAngle(dlg.dAngle);
                        rotate.Execute();

                    }
                    else
                    {
                        // 90xN度の場合は、CFviImageのGetRotatedImageでも回転できます。
                        //(0:0 度、1:90 度、2:180 度、3:270 度)

                        m_dst = m_image.GetRotatedImage((int)dlg.dAngle / 90);
                    }

                    // 描画imageのセット    
                    cFviImageView1.Image = m_dst;

                    //再描画
                    cFviImageView1.Refresh();
                }
            }
             catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }           

        }
        
        /// <summary>
        /// Trigger Modeコンボボックス
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// ノーマルモード・内部トリガモード・外部トリガモードの選択。
        /// </remarks>
        private void ComboBoxTrigger_SelectedIndexChanged(object sender, EventArgs e)
        {
            try
            {
                if (m_flgVideoOpened == true)
                {
                    m_video.Trigger = (uint)ComboBoxTrigger.SelectedIndex;
                    //弊社キャプチャボードはトリガーモードの設定後にセットアップタイムが必要になります｡
                    //本プログラムのセットアップタイムは必要最大値である350msを設定しています。
                    //キャプチャボードによってこの時間は異なります。
                    System.Threading.Thread.Sleep(350);
                }
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }


        }

        // <summary>
        /// Video Exposure値
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        /// <remarks>
        /// カメラ露光時間の設定。
        /// </remarks>
        private void NumericUpDownExposure_ValueChanged(object sender, EventArgs e)
        {
            try
            {
                if (m_flgVideoOpened == true)
                    m_video.ExposureTime = (uint)NumericUpDownExposure.Value;
            }
            catch (FVIL.CFviException ex)
            {
                //エラー処理
                MessageBox.Show(String.Format("ErrorCode={0}", ex.ErrorCode), "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
            catch (System.Exception ex)
            {
                //エラー処理
                MessageBox.Show(ex.Message, "Error", MessageBoxButtons.OK, MessageBoxIcon.Error);
            }
        }
    }
}